@@ -12,7 +12,7 @@ use Cwd qw/getcwd abs_path/;
 use base 'Clustericious::Command';
 
 # ABSTRACT: Clustericious command to stat Hypnotoad
-our $VERSION = '0.9939'; # VERSION
+our $VERSION = '0.9940'; # VERSION
 
 
 __PACKAGE__->attr(description => "Start a hypnotad web server.\n");
@@ -31,7 +31,7 @@ sub run {
     DEBUG "Config : $conf_string";
     my $exe = $0;
     DEBUG "Running hypnotoad : $exe";
-    $ENV{HYPNOTOAD_EXE} = "$0 hypnotoad";
+    $ENV{HYPNOTOAD_EXE} = "$0";
     my $sentinel = '/no/such/file/because/these/are/deprecated';
     if ( $ENV{HYPNOTOAD_CONFIG} && $ENV{HYPNOTOAD_CONFIG} ne $sentinel ) {
         WARN "HYPNOTOAD_CONFIG value $ENV{HYPNOTOAD_CONFIG} will be ignored";
@@ -55,6 +55,7 @@ sub run {
             }
         }
         my $toad = Mojo::Server::Hypnotoad->new;
+        $ENV{CLUSTERICIOUS_COMMAND_NAME} = 'hypnotoad';
         $toad->run($exe);
         WARN "hypnotoad exited";
         exit;
@@ -75,7 +76,7 @@ Clustericious::Command::hypnotoad - Clustericious command to stat Hypnotoad
 
 =head1 VERSION
 
-version 0.9939
+version 0.9940
 
 =head1 SYNOPSIS
 
